@@ -3,16 +3,7 @@ from django.conf import settings
 from django.contrib.sites.models import Site
 from django.template import loader, Context
 from zeropass import conf
-# only import the tasks if djcelery is in installed apps
-if 'djcelery' in settings.INSTALLED_APPS:
-    from zeropass.tasks import delete_token
 
-def set_deletion_task(sender, instance, **kwargs):
-    """set a token to be deleted by a task rather than management
-    command"""
-    if conf.CELERY_CLEANUP:
-        delete_token.apply_async((instance,), eta=instance.expires)
-        
 
 def send_email(sender, instance, **kwargs):
     """send the email to the person who requested the token"""
@@ -41,10 +32,10 @@ def send_email(sender, instance, **kwargs):
     #
     # build the message
     msg = EmailMultiAlternatives(
-            subject,
-            text_content,
-            settings.DEFAULT_FROM_EMAIL,
-            [instance.user.email])
+        subject,
+        text_content,
+        settings.DEFAULT_FROM_EMAIL,
+        [instance.user.email])
     #
     #
     # if we're sending HTML
